==> m3_db_utils-0.1.2.tar.gz: m3_db_utils-0.1.2/CHANGES.md <==
0.1.2

* EDUSCHL-17810 Добавление файлов в MANIFEST.in.

0.1.1

* EDUSCHL-17810 Добавление парсинга зависимостей из requirements.txt в setup.py.

0.1.0

* EDUSCHL-17810 Понижение версии Django до 1.11.29;
* EDUSCHL-17810 Обеспечение обратной совместимости.

0.0.7

* BOBUH-19787 Исправление опечаток в комментариях к коду;
* BOBUH-19787 Добавление поля order_number в модель-перечисление.

0.0.6

* BOBUH-18885 Исправление ошибки получения записей таблицы модели-перечисления, если значения модели-перечисления указываются в родительской модели-перечислении.

0.0.5

* BOBUH-18382 Исправление ошибки создания записей в таблице модели-перечисления, если значения модели-перечисления указываются в родительской модели-перечислении.

0.0.4

* BOBUH-18943 Отказ от зашитого title в модели-перечислении;
* BOBUH-18943 Добавление возможности указания более широкого набора полей в значении модели-перечисления, чем полей модели, для возможности использования значений связанных, но не хранящихся в базе данных;
* BOBUH-18943 Расширение существующих моделей-перечислений;
* BOBUH-18943 Удаление метода get_choices, для явного указания необходимости использования моделей-перечислений с внешними ключами;
* BOBUH-18943 Исправление ошибки с отсутствующим полем в значении модели-перечислении, имеющим дефолтное значение или необязательным в модели.

0.0.3

* BOBUH-18362 Замена значения модели-перечисления с кортежа на экземпляр класса; 
* BOBUH-18362 Добавлен патчинг значений моделей-перечислений ключами самих перечислений; 
* BOBUH-18362 В модели перечислении первичный ключ заменен на key.

0.0.2

* Добавление моделей-перечислений;
* Реализация механизмов для обновления значений моделей-перечислений в БД;
* Актуализация механизма сборки документации.

0.0.1

* Инициализация проекта
* Добавление каркаса документации

==> m3_db_utils-0.1.3.tar.gz: m3_db_utils-0.1.3/CHANGES.md <==
0.1.3

* EDUSCHL-17752 Добавлена совместимость с django 1.11 в классе актуализирующем значения моделей-перечислений;
* EDUSCHL-17752 Добавлены методы получения значений и ключей модели перечисления.

0.1.2

* EDUSCHL-17810 Добавление файлов в MANIFEST.in.

0.1.1

* EDUSCHL-17810 Добавление парсинга зависимостей из requirements.txt в setup.py.

0.1.0

* EDUSCHL-17810 Понижение версии Django до 1.11.29;
* EDUSCHL-17810 Обеспечение обратной совместимости.

0.0.7

* BOBUH-19787 Исправление опечаток в комментариях к коду;
* BOBUH-19787 Добавление поля order_number в модель-перечисление.

0.0.6

* BOBUH-18885 Исправление ошибки получения записей таблицы модели-перечисления, если значения модели-перечисления указываются в родительской модели-перечислении.

0.0.5

* BOBUH-18382 Исправление ошибки создания записей в таблице модели-перечисления, если значения модели-перечисления указываются в родительской модели-перечислении.

0.0.4

* BOBUH-18943 Отказ от зашитого title в модели-перечислении;
* BOBUH-18943 Добавление возможности указания более широкого набора полей в значении модели-перечисления, чем полей модели, для возможности использования значений связанных, но не хранящихся в базе данных;
* BOBUH-18943 Расширение существующих моделей-перечислений;
* BOBUH-18943 Удаление метода get_choices, для явного указания необходимости использования моделей-перечислений с внешними ключами;
* BOBUH-18943 Исправление ошибки с отсутствующим полем в значении модели-перечислении, имеющим дефолтное значение или необязательным в модели.

0.0.3

* BOBUH-18362 Замена значения модели-перечисления с кортежа на экземпляр класса; 
* BOBUH-18362 Добавлен патчинг значений моделей-перечислений ключами самих перечислений; 
* BOBUH-18362 В модели перечислении первичный ключ заменен на key.

0.0.2

* Добавление моделей-перечислений;
* Реализация механизмов для обновления значений моделей-перечислений в БД;
* Актуализация механизма сборки документации.

0.0.1

* Инициализация проекта
* Добавление каркаса документации
